function [GPM,HPWT,C,GRAD]=getZC(PX)

global c0 b1 b2 aF aH bM b3 b4
K=size(PX,1); % # of producer
J=size(PX,2); % # of vehicle for each producer

% P=PX(:,:,1)*1e4; % scaling Price variable back to dollar
XE=PX(:,:,2);  % Engine scaling variable
XT=PX(:,:,3);  % fuel-saving Technology variable
MPG=zeros(K,J);
HPWT=zeros(K,J);
GPM=zeros(K,J);
dGPMdXE=zeros(K,J);
dGPMdXT=zeros(K,J);
dMPGdXE=zeros(K,J);
dMPGdXT=zeros(K,J);
dHPWTdXE=zeros(K,J);

for k=1:K,
    for j=1:J
        % Fuel consumption (gpm)= 1 / fuel economy (mpg)
        % Then fuel consumption is multiplied with improvement ratio
        GPM(k,j)=1/(aF(3)*XE(k,j)^2+aF(2)*XE(k,j)+aF(1))*(1-XT(k,j));
        MPG(k,j)=1/GPM(k,j);
        dMPGdXE(k,j)=(2*aF(3)*XE(k,j)+aF(2))*(1-XT(k,j))^-1;
        dMPGdXT(k,j)=(aF(3).*XE(k,j)^2+aF(2)*XE(k,j)+aF(1))*(1-XT(k,j))^-2;
        dGPMdXE(k,j)=(-1*(aF(3)*XE(k,j)^2+aF(2)*XE(k,j)+aF(1))^-2)* ...
            (1-XT(k,j))*(2*aF(3)*XE(k,j)+aF(2));
        dGPMdXT(k,j)=-1./(aF(3).*XE(k,j)^2+aF(2)*XE(k,j)+aF(1));
        HPWT(k,j)= (aH(3)*XE(k,j)^2+ aH(2)*XE(k,j)+aH(1)); % unit: hp/1000lb
        dHPWTdXE(k,j) = (2*aH(3)*XE(k,j)+ aH(2));
    end
end

%  c0 = vehicle body cost
%  cE = JMD-2004 exp-engine-cost model 
%  cT = technology cost
%  C=c0+cE+cT  & scaled to per 10000 dollars
C=(c0 + b1*exp(b2*bM*XE) + b3*XT.^2+b4*XT ).*1e-4;
dCdXE=(b1*b2*bM*exp(b2*bM*XE))*1e-4;
dCdXT=(2*b3*XT+b4)*1e-4;

GRAD.dMPGdXE=dMPGdXE;
GRAD.dMPGdXT=dMPGdXT;
GRAD.dGPMdXE=dGPMdXE;
GRAD.dGPMdXT=dGPMdXT;
GRAD.dHPWTdXE=dHPWTdXE;
GRAD.dCdXE=dCdXE;
GRAD.dCdXT=dCdXT;
%%% all derivative terms are verified with numerical differenations - okay
