function [G,H]=pxfoc(PX,caseindex)
% caseindex: index for 6 cases
%        mm: a matrix with size(K,J)
%            its element is the index for large=1 or small=2 car

global J K ND
global draws beta sigma
global gasprice rho mpgstd
    P=PX(:,:,1); % scaling Price variable back to dollar
   XE=PX(:,:,2); % engine scaling variable
   XT=PX(:,:,3); % fuel-saving Technology variable
XEmuL=PX(:,:,4); % Lagrangian multiplier for XE lower bound (0.8)
XEmuU=PX(:,:,5); % Lagrangian multiplier for XE upper bound (2.0)
XTmuL=PX(:,:,6); % Lagrangian multiplier for XT lower bound (0)
XTmuU=PX(:,:,7); % Lagrangian multiplier for XT upper bound (20)

[GPM,HPWT,C,GRAD]=getZC(PX);
DPM=gasprice*GPM;
MPG=1./GPM;
 dMPGdXE=GRAD.dMPGdXE;
 dMPGdXT=GRAD.dMPGdXT;
 dGPMdXE=GRAD.dGPMdXE;
 dGPMdXT=GRAD.dGPMdXT;
dHPWTdXE=GRAD.dHPWTdXE;
   dCdXE=GRAD.dCdXE;
   dCdXT=GRAD.dCdXT;
   
B = repmat(beta,[K,1,ND]) ...
   +repmat(sigma,[K,1,ND]).*repmat(permute(draws,[3,2,1]),[K,1,1]);

% match demand coefficient units
% price: per $10,000
% Op-cost: cent per mile (100 * dollar per mile)
% hp/wt: HP per 100 lbs  (0.1 * hp/1000LB))
Z = [P,DPM*100,HPWT]; 
V = sum(repmat(Z,[1,1,ND]).*B,2);
EV= exp(V); 
%ev0=1; % add outside good (ev0=1) 
sumEV=sum(EV,1);
SD=EV./repmat(sumEV,[K,1,1]);
%s=mean(SD,3); 

% get FOC equations for zCAFEk not equal to CAFE-std
CAFEk=MPG; % CAFE harmonic average
delta=(mpgstd-CAFEk).*(mpgstd>CAFEk);

% three equations have been double checked
dVdP = B(:,1,:);
dVdXE= (100*gasprice)*B(:,2,:).*repmat(dGPMdXE,[1,1,ND]) + B(:,3,:).*repmat(dHPWTdXE,[1,1,ND]);
dVdXT= (100*gasprice)*B(:,2,:).*repmat(dGPMdXT,[1,1,ND]);
%
switch caseindex,
    case 1, % case 1: zCAFEk > std (surpassing)
        focP = SD.*( dVdP.*(1-SD).*repmat(P-C,[1,1,ND])+1);
        focXE= SD.*(dVdXE.*(1-SD).*repmat(P-C,[1,1,ND])-repmat(dCdXE,[1,1,ND]));
        focXT= SD.*(dVdXT.*(1-SD).*repmat(P-C,[1,1,ND])-repmat(dCdXT,[1,1,ND]));
        H =[ mean(focP,3);
             mean(focXE,3)+XEmuL-XEmuU;
             mean(focXT,3)+XTmuL-XTmuU;
             XEmuL.*(0.8-XE);
             XEmuU.*(XE-2.0);
             XTmuL.*(0-XT);
             XTmuU.*(XT-0.2); ];
    case 2, % case 2: zCAFEk = std (binding)
        focP = SD.*( dVdP.*(1-SD).*repmat(P-C,[1,1,ND])+1);
        funX = MPG-mpgstd;
        H=[mean(focP,3);
           funX]; 
    case 3, % case 3: zCAFEk < std (violating)
        focP = SD.*(dVdP .*(1-SD).*repmat(P-C-rho*delta,[1,1,ND])+1);
        focXE= SD.*(dVdXE.*(1-SD).*repmat(P-C-rho*delta,[1,1,ND])+repmat(rho*dMPGdXE-dCdXE,[1,1,ND]));
        focXT= SD.*(dVdXT.*(1-SD).*repmat(P-C-rho*delta,[1,1,ND])+repmat(rho*dMPGdXT-dCdXT,[1,1,ND]));
        H =[mean(focP ,3);
            mean(focXE,3)+XEmuL-XEmuU;
            mean(focXT,3)+XTmuL-XTmuU;
            XEmuL.*(0.8-XE);
            XEmuU.*(XE-2.0);
            XTmuL.*(0-XT);
            XTmuU.*(XT-0.2); ];
end

G=[];