% Use conditional FOC algorithm to solve multi-vehicle design responses
% all costs and prices are in 2007 dollars
% under CAFE regulations (6 cases: updated 2/23/2009)
% ---
% demand model: new 2007 demand model from Ward's Auto data
% vehicle model: meta-model from ADVISOR 2004
%    cost model: JMD 2004 exponential cost model
% ---
% current settings: each firm has a generic vehicle model

format compact
clc
clear all
global gasprice rho mpgstd
global beta sigma draws
global aF aH bM c0 b1 b2 b3 b4
global Q cI K J ND
load draws.mat % read saved normal random draws (draws)

%%%%%%%%% parameters to change %%%%%%%%%%%%%
K=10;  % # of producers (for calculating price only)
J=1;
mpgstd=35;   % CAFE mpg standard parameter
rho=55*1e-4; % CAFE penalty parameter per 10000 dollars
gasprice=2.50; 
draws=draws(:,1:3);
ND=length(draws);
Q=3; % mid-size market size 3 million
cI=550; % investment cost = $550 million

%%%% old meta-model: mid-size with 95kW engine, TX_AUTO4_4L60E
bM=95;
aF(3)= 4.8978; aF(2)=-24.74; aF(1)=48.83;  % unit: mpg
aH(3)=-0.4430; aH(2)=3.8733; aH(1)=0.1236; % coefficients for hp/100LB

% coefficient of technology-cost curve (from NHTSA 2008 report)
% the costs have been converted from 2006 to 2007 dollars
b3=85936; b4=-2177; % high (the base case in the study)
%b3=34121; b4=-847; % mean (underestimate technology costs)
%b3=16699; b4=-639; % low  (underestimate technology costs)

% cost coefficient from Michalek et al. JMD (2004)
% scaled from 2004 to 2007 dollars using Consumer Price Index
c0=7500/1.0724*1.1204;
b1=670.51/1.0724*1.1204;
b2=0.0063;

% 6/16/2009: new mixed logit model (normal distribution) 
% price/10000, dpm*100, HP/weight*100
% all normal distribution
 beta=[-0.9108 -0.1812  0.2417];
sigma=[ 0.4683  0.1447  0.0042];

%%%%%%%%% end of setting up parameters %%%%%%%%%%%%%%%%%%%%%
disp(sprintf('Gas-Price_gamma=%-0.2f Penalty_rho=%-0.0f CAFE-std_kappa=%-0.2f',gasprice,rho*1e4,mpgstd));
options = optimset('Display','Off','TolX',1e-8,'TolFun',1e-8,'TolCon',1e-8,...
                   'LargeScale','off','Algorithm','active-set');
PX=zeros(K,J,3);
PX(:,:,1)=2; PX(:,:,2)=1; PX(:,:,3)=0.1;
pxk0=[ 2,  1,    0.1];
  lb=[ 0,  0.8,  0];
  ub=[10,  2.0,  0.2];

PISOL=zeros(K,1);
PXold=zeros(K,J,3);
flag=0;
r=0;
while (flag==0),
    disp('---');
    r=r+1;
    for k=1:K
        [pxjsol,nfval,exitflag]=fmincon(@profitk,pxk0,[],[],[],[],lb,ub,[],options,k,PX);
        [gpm,hpwt,c]=getZC(reshape(pxjsol,[1,1,3]));
        mpg=1/gpm;
        disp(sprintf('round=%d k=%1d p=%-0.4f xE=%-0.3f xT=%-0.3f profit=%-0.0f flag=%1d CAFE=%-0.2f', ...
             r,k,pxjsol(1),pxjsol(2),pxjsol(3),-nfval*1e4,exitflag,mpg));
        if exitflag >=1,
            PISOL(k)=-nfval;
            PX(k,1,:)=pxjsol;
        end
    end
    if sum(sum(abs(PX-PXold)<=1e-4))==K*3,
        flag=1;
    end
    PXold=PX;
end
